from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.schema_0 import Schema0






T = TypeVar("T", bound="UpdateUserRequest")



@_attrs_define
class UpdateUserRequest:
    """ 
        Attributes:
            email (str):
            name (str):
            role (Schema0):
            is_disabled (bool):
     """

    email: str
    name: str
    role: Schema0
    is_disabled: bool
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        email = self.email

        name = self.name

        role = self.role.value

        is_disabled = self.is_disabled


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "email": email,
            "name": name,
            "role": role,
            "isDisabled": is_disabled,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email")

        name = d.pop("name")

        role = Schema0(d.pop("role"))




        is_disabled = d.pop("isDisabled")

        update_user_request = cls(
            email=email,
            name=name,
            role=role,
            is_disabled=is_disabled,
        )


        update_user_request.additional_properties = d
        return update_user_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
